@@ -1,4 +1,4 @@
-#! /usr/bin/perl -w
+#! /usr/bin/perl
 #
 # reads a tin filter file with regexp filters on STDIN and turns all case
 # insensitive regexp into case sensitive ones whenever possible, as case
@@ -21,7 +21,10 @@
 # buggy
 require 5.004;
 
-$mod=""; 	# (?i) modifer
+use strict;
+use warnings;
+
+$mod=""; 	# (?i) modifier
 
 while (defined($line = <>)) {
 	chomp $line;
